##  Before You Start
Build an inventory of architectural data in SAP LeanIX. Import applications, business capabilities, organizations, and other fact sheet types. To learn how to get started, see [Application Portfolio Assessment](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment?locale=en-US&state=PRODUCTION&version=CLOUD "Establish transparency and governance over your as-is landscape to identify optimization opportunities and unlock further use cases.").
### Required Products and Extensions
  * Products:
    * SAP LeanIX Application Portfolio Management (base product): Build your inventory and collect AI-related data.
    * SAP LeanIX Architecture and Road Map Planning (additional product): Plan transformations involving AI technologies.
  * Extensions to the meta model:
    * AI governance: This extension offers a structured framework for tracking, managing, and evaluating organizations' AI usage, risks, and potential. To learn more, see [AI Governance Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/meta-model-ai-governance-extension?locale=en-US&state=PRODUCTION&version=CLOUD "Improve AI governance and adoption in your organization. Track and manage AI usage, evaluate risks, and assess AI potential.").
    * AI agent: This extension helps you model and govern AI agents and MCP servers to track the adoption of your agentic AI strategy. To learn more, see [AI Agent Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/ai-agent-extension-to-meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Activate an optional meta model extension to model and govern your organization’s AI agents and MCP servers.").
